## This spec is based on kolab's spec from the OBS

%define _disable_ld_no_undefined 1

# major is the part of the library name after the .so
%define major 0
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d


%global with_systemd 1

%global _name cyrus-imapd

%global ssl_pem_file %{_sysconfdir}/pki/%{_name}/%{_name}.pem


%global _cyrususer cyrus
%global _cyrusgroup mail
%global _cyrexecdir %{_exec_prefix}/lib/%{_name}

%global real_version 2.5.15

##
## Options
##

%global with_bdb        1
%global with_mysql      1
%global with_pgsql      1

%global with_dav        0
%global with_tcpwrap    1
%global __brp_check_rpaths %{nil}

Name:               cyrus-imapd
Summary:            A high-performance mail server with IMAP, POP3, NNTP and SIEVE support
Version:            %{real_version}
Release:            %mkrel 10
License:            BSD
Group:              System/Servers
URL:                https://www.cyrusimap.org

# Upstream sources
Source0:            https://www.cyrusimap.org/releases/%{_name}-%{real_version}.tar.gz
Source1:            cyrus-imapd.imap-2.5.x-conf
Source2:            cyrus-imapd.cvt_cyrusdb_all
Source3:            cyrus-imapd.magic

# Distribution specific sources
Source11:           cyrus-imapd.logrotate
Source12:           cyrus-imapd.pam-config
Source13:           cyrus-imapd.cron-daily

# SysVinit
Source22:           cyrus-imapd.sysconfig


# Systemd support
Source31:           cyrus-imapd.service
Source32:           cyr_systemd_helper

##
## Patches
##
Patch0:             cyrus-imapd-2.5.11-assert.patch
Patch1:             cyrus-imapd-2.5.13-conflicting-types-for-gettid.patch
Patch2:             CVE-2021-33582_1.patch
Patch3:             CVE-2021-33582_2.patch

Provides:           imap
Provides:           imap-server

##
## Build Requirements
##
BuildRequires:      autoconf
BuildRequires:      automake
BuildRequires:      bison
BuildRequires:      pkgconfig(libsasl2)
BuildRequires:      pkgconfig(cunit)
BuildRequires:      sasl-plug-digestmd5
BuildRequires:      sasl-plug-plain
BuildRequires:      pkgconfig(libxml-2.0)

%if 0%{?with_bdb}
BuildRequires:      db5-devel
%endif
BuildRequires:      flex
#BuildRequires:     gcc-c++
BuildRequires:      gcc
BuildRequires:      groff
BuildRequires:      pkgconfig(jansson)
BuildRequires:      pkgconfig(krb5)

%if 0%{?with_dav}
BuildRequires:      pkgconfig(libical)
%endif

BuildRequires:      libtool
BuildRequires:      pkgconfig(uuid)

%if 0%{?with_mysql}
BuildRequires:      mysql-devel
%endif
BuildRequires:      openldap-devel
BuildRequires:      pkgconfig(openssl)
BuildRequires:      perl(ExtUtils::MakeMaker)

BuildRequires:      perl-devel
BuildRequires:      pkgconfig

%if 0%{?with_pgsql}
BuildRequires:      postgresql-devel
%endif

%if 0%{?with_dav}
BuildRequires:      pkgconfig(sqlite3)
%endif

%if 0%{?with_tcpwrap}
BuildRequires:      tcp_wrappers
%endif

BuildRequires:      transfig
%if 0
# Disable the xapian-core requirement
BuildRequires:      xapian-core-devel
%endif

Requires:           db5-utils
Requires:           file
## Spuhler 2016-01-22: I don't think we need this (Fedora has it in the perl-libs pacakge
#Requires:           perl(:MODULE_COMPAT_%%(eval "`%%{__perl} -V:version`"; echo $version))
Requires(post):     coreutils
Requires(post):     e2fsprogs
Requires(post):     findutils
Requires(post):     grep
Requires(post):     make
Requires(post):     openssl
Requires(post):     perl
Requires(preun):    coreutils
Requires(pre):      /usr/sbin/useradd /usr/sbin/groupadd
Requires(preun):    /usr/sbin/userdel /usr/sbin/groupdel
Requires(post):     rpm-helper >= 0.24.8-1
Requires(preun):    rpm-helper >= 0.24.8-1


Obsoletes:          %{name}-perl < %{version}-%{release}
Provides:           %{name}-perl = %{version}-%{release}
Obsoletes:          %{name}-utils < %{version}-%{release}
Provides:           %{name}-utils = %{version}-%{release}

%description
The %{name} package contains the core of the Cyrus IMAP server.
It is a scaleable enterprise mail system designed for use from
small to large enterprise environments using standards-based
internet mail technologies.

A full Cyrus IMAP implementation allows a seamless mail and bulletin
board environment to be set up across multiple servers. It differs from
other IMAP server implementations in that it is run on "sealed"
servers, where users are not normally permitted to log in and have no
system account on the server. The mailbox database is stored in parts
of the filesystem that are private to the Cyrus IMAP server. All user
access to mail is through software using the IMAP, POP3 or KPOP
protocols. It also includes support for virtual domains, NNTP,
mailbox annotations, and much more. The private mailbox database design
gives the server large advantages in efficiency, scalability and
administratability. Multiple concurrent read/write connections to the
same mailbox are permitted. The server supports access control lists on
mailboxes and storage quotas on mailbox hierarchies.

The Cyrus IMAP server supports the IMAP4rev1 protocol described
in RFC 3501. IMAP4rev1 has been approved as a proposed standard.
It supports any authentication mechanism available from the SASL
library, imaps/pop3s/nntps (IMAP/POP3/NNTP encrypted using SSL and
TLSv1) can be used for security. The server supports single instance
store where possible when an email message is addressed to multiple
recipients, SIEVE provides server side email filtering.

%package -n     %{libname}
Summary:        Cyrus IMAP server library files
Group:          System/Libraries

%description -n %{libname}
The %{name}-lib package contains the library for cyrus-imapd

%package -n     %{develname}
Summary:        Cyrus IMAP server development files
Group:          Development/Other
Requires:       %{libname} = %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
The %{name}-devel package contains header files and libraries
necessary for developing applications which use the imclient library.


%package -n	perl-Cyrus
Summary:	Cyrus IMAPd utility Perl modules
Group:		Development/Perl

%description -n	perl-Cyrus
This package contains Perl modules necessary to use the Cyrus server
administrative utilities.

The main package is %{name}.

%prep
%setup -q -n %{_name}-%{real_version}%{?dot_snapshot_version}
%autopatch -p1

%if 0%{?with_bdb} < 1
sed -i -e 's/,berkeley//g' cunit/db.testc
sed -r -i -e 's/"berkeley(|-[a-z-]+)", //g' lib/imapoptions
%endif

# only to update config.* files
autoreconf -vi || (libtoolize --force && autoreconf -vi)

# Modify docs master --> cyrus-master
%{__perl} -pi -e "s@master\(8\)@cyrus-master(8)@" man/*5 man/*8 lib/imapoptions
%{__sed} -i -e 's|\([^-]\)master|\1cyrus-master|g;s|^master|cyrus-master|g;s|Master|Cyrus-master|g;s|MASTER|CYRUS-MASTER|g' \
        man/master.8 doc/man.html

%if 0%{?with_dav}
# Modify docs httpd --> cyrus-httpd
%{__perl} -pi -e "s@httpd\(8\)@cyrus-httpd(8)@" man/*5 man/*8 lib/imapoptions
%{__sed} -i -e 's|\([^-]\)httpd|\1cyrus-httpd|g;s|^httpd|cyrus-httpd|g;s|Httpd|Cyrus-httpd|g;s|HTTPD|CYRUS-HTTPD|g' \
        man/httpd.8 doc/man.html
%endif

# Modify path in perl scripts
find . -type f -name "*.pl" | xargs %{__perl} -pi -e "s@/usr/local/bin/perl@%{__perl}@"

# modify lmtp socket path in .conf files
%{__perl} -pi -e "s@/var/imap/@%{_var}/lib/imap/@" master/conf/*.conf doc/cyrusv2.mc doc/m4/%{name}-sendmail-8.12.9-cyrusv2.m4

# enable idled in .conf files to prevent error messages
%{__perl} -pi -e "s/#  idled/  idled/" master/conf/*.conf

%build
CPPFLAGS="-I%{_includedir}/et -I%{_includedir}/kerberosIV"
export CPPFLAGS
CFLAGS="$RPM_OPT_FLAGS -fPIC"
export CFLAGS
CXXFLAGS="$RPM_OPT_FLAGS -fPIC"; 
export CXXFLAGS
CCDLFLAGS="-rdynamic"
export CCDLFLAGS
LDFLAGS="-L%{_libdir}"
export LDFLAGS

%configure \
    --enable-event-notification \
    --enable-gssapi \
    --enable-idled \
    --enable-murder \
    --enable-netscapehack \
    --enable-nntp \
    --enable-replication \
    --enable-unit-tests \
%if 0
    --enable-xapian \
%endif
%if 0%{?with_bdb}
    --with-bdb-incdir=%{_includedir}/db4 \
%else
    --without-bdb \
%endif
    --with-cyrus-prefix=%{_cyrexecdir} \
    --with-extraident="Kolab-%{version}-%{release}" \
%if 0%{?with_tcpwrap} < 1
    --without-wrap \
%endif
%if 0%{?with_dav}
    --enable-http \
%endif
    --with-krbimpl=mit \
    --with-ldap=/usr \
%if 0%{?with_mysql}
    --with-mysql=%{_prefix} \
    --with-mysql-incdir=%{_includedir}/mysql/ \
    --with-mysql \
%endif
    --with-perl=%{__perl} \
%if 0%{?with_pgsql}
    --with-pgsql=%{_includedir} \
%endif
    --with-service-path=%{_cyrexecdir} \
    --with-syslogfacility=MAIL

%make_build

%install


# Fix permissions on perl programs
find . -type f -name "*.pl" -exec %{__chmod} 755 {} \;

# Do what the regular make install does
%{__make} install DESTDIR=%{buildroot} PREFIX=%{_prefix} mandir=%{_mandir} INSTALLDIRS=vendor

# Install tools
for tool in tools/* ; do
  test -f ${tool} && %{__install} -m 755 ${tool} %{buildroot}%{_cyrexecdir}/
done

# Create directories
%{__install} -d \
  %{buildroot}%{_sysconfdir}/{logrotate.d,pam.d,cron.daily} \
  %{buildroot}%{_libdir}/sasl \
  %{buildroot}%{_var}/spool/imap \
  %{buildroot}%{_var}/lib/imap/{user,quota,proc,log,msg,socket,db,sieve,sync,md5,rpm,backup,meta} \
  %{buildroot}%{_var}/lib/imap/ptclient \
  %{buildroot}%{_sysconfdir}/pki/%{_name} \
  doc/contrib

# Install additional files
%{__install} -p -m 644 master/conf/prefork.conf %{buildroot}%{_sysconfdir}/cyrus.conf
%{__install} -p -m 644 %{SOURCE1}    %{buildroot}%{_sysconfdir}/imapd.conf
%{__install} -p -m 755 %{SOURCE2}   %{buildroot}%{_cyrexecdir}/cvt_cyrusdb_all
%{__install} -p -m 644 %{SOURCE3}   %{buildroot}%{_var}/lib/imap/rpm/magic
%{__install} -p -m 644 %{SOURCE11}    %{buildroot}%{_sysconfdir}/logrotate.d/%{_name}
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/pop
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/imap
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/sieve
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/mupdate
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/lmtp
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/nntp
%{__install} -p -m 644 %{SOURCE12}    %{buildroot}%{_sysconfdir}/pam.d/csync
%{__install} -p -m 755 %{SOURCE13}   %{buildroot}%{_sysconfdir}/cron.daily/%{_name}
%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig/
%{__install} -p -m 644 %{SOURCE22}   %{buildroot}%{_sysconfdir}/sysconfig/%{_name}
%{__install} -p -D -m 644 %{SOURCE31}   %{buildroot}%{_unitdir}/cyrus-imapd.service
%{__install} -p -D -m 755 %{SOURCE32}   %{buildroot}%{_cyrexecdir}/cyr_systemd_helper


# Cleanup of doc dir
find doc perl -name CVS -type d | xargs -r %{__rm} -rf
find doc perl -name .cvsignore -type f | xargs -r %{__rm} -f
%{__rm} -f doc/Makefile.dist*
%{__rm} -f doc/text/htmlstrip.c
%{__rm} -f doc/text/Makefile
%{__rm} -rf doc/man

# fix permissions on perl .so files
find %{buildroot}%{perl_vendorarch} -type f -name "*.so" -exec %{__chmod} 755 {} \;

# fix conflicts with uw-imap
mv %{buildroot}%{_mandir}/man8/imapd.8 %{buildroot}%{_mandir}/man8/imapd.8cyrus
mv %{buildroot}%{_mandir}/man8/pop3d.8 %{buildroot}%{_mandir}/man8/pop3d.8cyrus

# Install templates
%{__install} -m 755 -d doc/conf
%{__install} -m 644 master/conf/*.conf doc/conf/

# Generate db config file
( grep '^{' lib/imapoptions | grep _db | grep -v _db_path | cut -d'"' -f 2,4 | \
  sed -e 's/^ *//' -e 's/-nosync//' -e 's/ *$//' -e 's/"/=/'
  echo sieve_version=2.2.3 ) | sort > %{buildroot}%{_var}/lib/imap/rpm/db.cfg

# create the ghost pem file
touch %{buildroot}%{ssl_pem_file}

# Rename 'master' binary and manpage to avoid clash with postfix
%{__mv} -f %{buildroot}%{_cyrexecdir}/master        %{buildroot}%{_cyrexecdir}/cyrus-master
%{__mv} -f %{buildroot}%{_mandir}/man8/master.8     %{buildroot}%{_mandir}/man8/cyrus-master.8

# Rename 'httpd' binary and manpage to avoid clash with apache httpd
%if 0%{?with_dav}
%{__mv} -f %{buildroot}%{_cyrexecdir}/httpd         %{buildroot}%{_cyrexecdir}/cyrus-httpd
%{__mv} -f %{buildroot}%{_mandir}/man8/httpd.8      %{buildroot}%{_mandir}/man8/cyrus-httpd.8
%endif

# Rename 'fetchnews' binary and manpage to avoid clash with leafnode
%{__mv} -f %{buildroot}%{_cyrexecdir}/fetchnews     %{buildroot}%{_cyrexecdir}/cyrfetchnews
%{__mv} -f %{buildroot}%{_mandir}/man8/fetchnews.8  %{buildroot}%{_mandir}/man8/cyrfetchnews.8
%{__perl} -pi -e 's|fetchnews|cyrfetchnews|g;s|Fetchnews|Cyrfetchnews|g;s/FETCHNEWS/CYRFETCHNEWS/g' \
        %{buildroot}%{_mandir}/man8/cyrfetchnews.8

# compress manpages
[ -x /usr/lib/rpm/brp-compress ] && /usr/lib/rpm/brp-compress

# remove executable bit from docs
for ddir in doc perl/imap/examples
do
  find $ddir -type f -exec %{__chmod} -x {} \;
done

# Remove installed but not packaged files
%{__rm} -f %{buildroot}%{_cyrexecdir}/htmlstrip.c
%{__rm} -f %{buildroot}%{_cyrexecdir}/not-mkdep
%{__rm} -f %{buildroot}%{_cyrexecdir}/config2header*
%{__rm} -f %{buildroot}%{_cyrexecdir}/config2man
%{__rm} -f %{buildroot}%{_cyrexecdir}/pop3proxyd
find %{buildroot} -type f -name "perllocal.pod" -exec %{__rm} -vf {} \;
find %{buildroot} -type f -name ".packlist" -exec %{__rm} -vf {} \;
find %{buildroot} -type f -name ".gitignore" -exec %{__rm} -vf {} \;
find %{buildroot} -type f -name "cyr_buildinfo" -exec %{__rm} -vf {} \;
find %{buildroot} -type f -name "cyr_buildinfo-2.5.13-1.mga7.x86_64.debug" -exec %{__rm} -vf {} \;
%{__rm} -f %{buildroot}%{_mandir}/man8/syncnews.8*
find %{buildroot}%{perl_vendorarch} -type f -name "*.bs" -exec %{__rm} -vf {} \;

%check
make check || :


%pre
if [ $1 == 1 ]; then
    # Create 'cyrus' user on target host
    /usr/sbin/groupadd -r saslauth 2> /dev/null || :
    /usr/sbin/useradd -c "Cyrus IMAP Server" -d %{_var}/lib/imap -g %{_cyrusgroup} \
        -G saslauth -s /sbin/nologin -r %{_cyrususer} 2> /dev/null || :
fi

## From documentation:
# It is strongly recommended to shut down the Cyrus IMAP services 
# before performing the upgrade, as the newer binaries will end up 
# writing to mailboxes.db in a way that is not compatible with the older binaries 
# (that would otherwise still be running).
if [ $1 == 2 ]; then
     /usr/bin/systemctl stop cyrus-imapd
fi

%post
CHATTRSYNC=0

if [ -f "%{_sysconfdir}/sysconfig/cyrus-imapd" ]; then
    source %{_sysconfdir}/sysconfig/cyrus-imapd
fi

if [ $CHATTRSYNC -eq 1 ]; then
    # Force synchronous updates of files in the following directories
    chattr -R +S \
        $(grep ^configdirectory: /etc/imapd.conf | cut -d':' -f2) \
        $(grep ^partition- /etc/imapd.conf | cut -d':' -f2) \
        $(grep ^metapartition- /etc/imapd.conf | cut -d':' -f2) 2>/dev/null ||:
fi

# Create SSL certificates
%_create_ssl_certificate cyrus-imapd
chown %{_cyrususer}:%{_cyrusgroup} /etc/pki/tls/private/cyrus-imapd.pem

# These commands may fail in a docker container, which may not
# have a /usr/bin/systemctl with a 'preset' command
%_post_service cyrus-imapd

%preun
%_preun_service cyrus-imapd

%files
%doc COPYING README
%doc doc/*
%config(noreplace) %{_sysconfdir}/cyrus.conf
%config(noreplace) %{_sysconfdir}/imapd.conf
%{_unitdir}/cyrus-imapd.service
%{_cyrexecdir}/cyr_systemd_helper
%dir %{_sysconfdir}/pki
%config(noreplace) %{_sysconfdir}/logrotate.d/%{_name}
%attr(0640,root,%{_cyrusgroup}) %config(noreplace) %{_sysconfdir}/sysconfig/%{_name}
%config(noreplace) %{_sysconfdir}/pam.d/pop
%config(noreplace) %{_sysconfdir}/pam.d/imap
%config(noreplace) %{_sysconfdir}/pam.d/sieve
%config(noreplace) %{_sysconfdir}/pam.d/lmtp
%config(noreplace) %{_sysconfdir}/pam.d/mupdate
%config(noreplace) %{_sysconfdir}/pam.d/csync
%config(noreplace) %{_sysconfdir}/pam.d/nntp
%attr(0755,root,root) %{_bindir}/cyradm
%{_bindir}/imtest
%{_bindir}/installsieve
%{_bindir}/lmtptest
%{_bindir}/mupdatetest
%{_bindir}/nntptest
%{_bindir}/pop3test
%{_bindir}/sieveshell
%{_bindir}/sivtest
%{_bindir}/smtptest
%{_bindir}/synctest
%{_sysconfdir}/cron.daily/%{_name}
%dir %{_cyrexecdir}
%{_cyrexecdir}/arbitron
%{_cyrexecdir}/arbitronsort.pl
%{_cyrexecdir}/chk_cyrus
%{_cyrexecdir}/compile_st.pl
%{_cyrexecdir}/convert-sieve.pl
%{_cyrexecdir}/cyr_deny
%{_cyrexecdir}/cyr_df
%{_cyrexecdir}/cyr_info
#%%{_cyrexecdir}/ctl_conversationsdb
%{_cyrexecdir}/ctl_cyrusdb
%{_cyrexecdir}/ctl_deliver
%{_cyrexecdir}/ctl_mboxlist
#%%{_cyrexecdir}/ctl_zoneinfo
%{_cyrexecdir}/cvt_cyrusdb
%{_cyrexecdir}/cyr_dbtool
%{_cyrexecdir}/cyr_expire
%{_cyrexecdir}/cyr_sequence
%{_cyrexecdir}/cyr_synclog
%{_cyrexecdir}/cyr_userseen
%{_cyrexecdir}/cyrdump
%if 0%{?with_dav}
%{_cyrexecdir}/cyrus-httpd
%{_cyrexecdir}/dav_reconstruct
%{_cyrexecdir}/ctl_zoneinfo
%endif
%{_cyrexecdir}/cyrus-master
%{_cyrexecdir}/deliver
%{_cyrexecdir}/dohash
%{_cyrexecdir}/fixsearchpath.pl
%{_cyrexecdir}/fud
%{_cyrexecdir}/git-version.sh
#%%{_cyrexecdir}/hammer_cyrusdb
%{_cyrexecdir}/imapd
%{_cyrexecdir}/ipurge
%exclude %{_cyrexecdir}/jenkins-build.sh
%{_cyrexecdir}/lmtpd
%{_cyrexecdir}/lmtpproxyd
%{_cyrexecdir}/masssievec
%{_cyrexecdir}/mbexamine
%{_cyrexecdir}/mbpath
%{_cyrexecdir}/mbtool
#%%{_cyrexecdir}/message_test
%{_cyrexecdir}/migrate-metadata
%{_cyrexecdir}/mkimap
%{_cyrexecdir}/mknewsgroups
%{_cyrexecdir}/notifyd
%{_cyrexecdir}/pop3d
%{_cyrexecdir}/quota
%{_cyrexecdir}/reconstruct
%{_cyrexecdir}/rehash
#%%{_cyrexecdir}/search_test
%{_cyrexecdir}/sievec
%{_cyrexecdir}/sieved
%{_cyrexecdir}/smmapd
#%%{_cyrexecdir}/squat_dump
%{_cyrexecdir}/squatter
%{_cyrexecdir}/timsieved
%{_cyrexecdir}/tls_prune
%{_cyrexecdir}/translatesieve
%{_cyrexecdir}/undohash
%{_cyrexecdir}/unexpunge
%{_cyrexecdir}/upgradesieve
%{_cyrexecdir}/cvt_cyrusdb_all
%{_cyrexecdir}/idled
%{_cyrexecdir}/mupdate
%{_cyrexecdir}/mupdate-loadgen.pl
%{_cyrexecdir}/proxyd
%{_cyrexecdir}/sync_client
%{_cyrexecdir}/sync_reset
%{_cyrexecdir}/sync_server
%{_cyrexecdir}/cyrfetchnews
%{_cyrexecdir}/nntpd
%{_cyrexecdir}/ptdump
%{_cyrexecdir}/ptexpire
%{_cyrexecdir}/ptloader
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/backup
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/db
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/log
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/meta
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/md5
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/msg
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %{_var}/lib/imap/proc
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %{_var}/lib/imap/ptclient
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/quota
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/rpm
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/sieve
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %{_var}/lib/imap/socket
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/sync
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/lib/imap/user
%attr(0750,%{_cyrususer},%{_cyrusgroup}) %dir %{_var}/spool/imap
%{_libdir}/*.so.*
%{_var}/lib/imap/rpm/*
%doc perl/imap/README
%doc perl/imap/Changes
%doc perl/imap/examples
%dir %{perl_vendorarch}/Cyrus
%dir %{perl_vendorarch}/Cyrus/IMAP
%{perl_vendorarch}/Cyrus/IMAP/Admin.pm
%{perl_vendorarch}/Cyrus/IMAP/Shell.pm
%{perl_vendorarch}/Cyrus/IMAP/IMSP.pm
%{perl_vendorarch}/Cyrus/IMAP.pm
%dir %{perl_vendorarch}/Cyrus/SIEVE
%{perl_vendorarch}/Cyrus/SIEVE/managesieve.pm
%dir %{perl_vendorlib}/Cyrus/
%dir %{perl_vendorlib}/Cyrus/Annotator
%{perl_vendorlib}/Cyrus/Annotator/Daemon.pm
%{perl_vendorlib}/Cyrus/Annotator/Message.pm
%dir %{perl_vendorarch}/auto
%dir %{perl_vendorarch}/auto/Cyrus
%dir %{perl_vendorarch}/auto/Cyrus/IMAP
%{perl_vendorarch}/auto/Cyrus/IMAP/IMAP.so
%dir %{perl_vendorarch}/auto/Cyrus/SIEVE
%dir %{perl_vendorarch}/auto/Cyrus/SIEVE/managesieve
%{perl_vendorarch}/auto/Cyrus/SIEVE/managesieve/managesieve.so
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%dir %{_sysconfdir}/pki/%{_name}
%attr(0640,root,%{_cyrusgroup}) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{ssl_pem_file}


%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%defattr(0644,root,root,0755)
%{_includedir}/cyrus
%{_libdir}/pkgconfig/*cyrus*.pc
%{_libdir}/*.so

%files -n perl-Cyrus
%doc perl/imap/Changes perl/imap/examples
%{perl_vendorarch}/auto/Cyrus
%{perl_vendorarch}/Cyrus
%{_mandir}/man3/Cyrus*


%changelog
* Tue Jan 03 2023 umeabot <umeabot> 2.5.15-10.mga9
+ Revision: 1929538
- Rebuild to use libldap-2.5 instead of 2.4

* Tue Jun 21 2022 ns80 <ns80> 2.5.15-9.mga9
+ Revision: 1865330
- add patches from Debian for CVE-2021-33582 (mga#30079)

* Tue Jun 07 2022 umeabot <umeabot> 2.5.15-8.mga9
+ Revision: 1863426
- Rebuild for Perl 5.36

* Sun Apr 03 2022 umeabot <umeabot> 2.5.15-7.mga9
+ Revision: 1841233
- Mageia 9 Mass Rebuild

* Wed Mar 09 2022 mrambo3501 <mrambo3501> 2.5.15-6.mga9
+ Revision: 1790221
- fix files list
- disable rpath checking
+ wally <wally>
- rebuild for openssl 3.0.0

* Mon May 24 2021 umeabot <umeabot> 2.5.15-4.mga9
+ Revision: 1727884
- Rebuild for perl 5.34

* Thu Jun 18 2020 umeabot <umeabot> 2.5.15-3.mga8
+ Revision: 1596045
- Rebuild for perl 5.32

* Tue Feb 18 2020 umeabot <umeabot> 2.5.15-2.mga8
+ Revision: 1541128
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Dec 20 2019 daviddavid <daviddavid> 2.5.15-1.mga8
+ Revision: 1469203
- new version: 2.5.15, fixes CVE-2019-19783 (25913)

* Fri Nov 15 2019 daviddavid <daviddavid> 2.5.14-1.mga8
+ Revision: 1460421
- new version: 2.5.14

* Wed Aug 28 2019 daviddavid <daviddavid> 2.5.13-3.mga8
+ Revision: 1434660
- add patch to fix conflicting types for 'gettid' with glibc 2.30
+ tmb <tmb>
- rebuild for perl 5.30
- rebuild for perl 5.30

* Thu Jul 18 2019 mrambo3501 <mrambo3501> 2.5.13-1.mga8
+ Revision: 1422536
- version 2.5.13 fixes CVE-2019-11356 (mga#25134)

* Sat Dec 29 2018 luigiwalser <luigiwalser> 2.5.11-7.mga7
+ Revision: 1346023
- rebuild for net-snmp

* Sun Sep 23 2018 umeabot <umeabot> 2.5.11-6.mga7
+ Revision: 1297392
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 daviddavid <daviddavid> 2.5.11-5.mga7
+ Revision: 1249749
- rebuild for new perl 5.28.0

* Sat Dec 23 2017 wally <wally> 2.5.11-4.mga7
+ Revision: 1184224
- rebuild for new mariadb

* Thu Aug 31 2017 pterjan <pterjan> 2.5.11-3.mga7
+ Revision: 1150250
- Rebuild for perl ABI changes

* Mon Jul 24 2017 cjw <cjw> 2.5.11-2.mga7
+ Revision: 1129751
- patch0: fix build
+ neoclust <neoclust>
- Rebuild against new Perl 5.26

* Tue May 16 2017 luigiwalser <luigiwalser> 2.5.11-1.mga6
+ Revision: 1102214
- 2.5.11

* Sun Jan 01 2017 luigiwalser <luigiwalser> 2.5.10-1.mga6
+ Revision: 1079128
- 2.5.10

* Sat May 28 2016 spuhler <spuhler> 2.5.8-1.mga6
+ Revision: 1019000
- reversed dav enabled, it doesn't build with current gcc
- upgrade to vers. 2.5.8
  * enabled dav as the build has been fixed upstream

* Thu Apr 28 2016 spuhler <spuhler> 2.5.7-14.mga6
+ Revision: 1007470
- changed create_ssl_certificate to do it the mga way, use the macro

* Wed Mar 23 2016 spuhler <spuhler> 2.5.7-13.mga6
+ Revision: 994690
- rebuild with new arm db53

* Wed Mar 23 2016 spuhler <spuhler> 2.5.7-12.mga6
+ Revision: 994682
- fixed Source numbers
- updated Requires and BuildRequires to db5
  * BS linked ageains db53 anyway

* Tue Mar 22 2016 spuhler <spuhler> 2.5.7-11.mga6
+ Revision: 993851
- fix cyrus-imapd.sysconfig

* Wed Mar 16 2016 luigiwalser <luigiwalser> 2.5.7-10.mga6
+ Revision: 992051
- finish fixing service macros

* Sat Mar 12 2016 spuhler <spuhler> 2.5.7-9.mga6
+ Revision: 989656
- cyrus-imapd.imap-2.3.x-conf upgraded to vers 2.5
- systemd mga macros used

* Fri Mar 11 2016 spuhler <spuhler> 2.5.7-8.mga6
+ Revision: 989315
- fixed systemd file names

* Wed Mar 02 2016 umeabot <umeabot> 2.5.7-7.mga6
+ Revision: 983347
- Rebuild for openssl

* Sun Feb 28 2016 oden <oden> 2.5.7-6.mga6
+ Revision: 980336
- rebuilt for postgresql 9.5.x
- rebuilt for postgresql 9.5.x

* Thu Feb 18 2016 spuhler <spuhler> 2.5.7-5.mga6
+ Revision: 965084
- disabled dav -build as it doesn't build
- stopping the deamon before upgrading (per docu recom)

* Fri Jan 22 2016 spuhler <spuhler> 2.5.7-3.mga6
+ Revision: 926578
- commented out "Requires:perl(:MODULE_COMPAT_%%(eval "`%%{__perl} -V:version`"; echo $version))"
- mageia does not provided it. Fedora has it in the perl-lib package as a provides

* Thu Jan 21 2016 spuhler <spuhler> 2.5.7-2.mga6
+ Revision: 926343
- added BuildRequires:  pkgconfig(sqlite3)
- added BuildRequires: pkgconfig(libxml-2.0)
- bumped rel to make it build
- changed teh libs package the mga way
- some cleanup
- added options
- added define _disable_ld_no_undefined 1 to make it build
- added missing files
- fixed group
- update to vers. 2.5.7
 * first build

* Tue Jan 12 2016 luigiwalser <luigiwalser> 2.4.18-2.mga6
+ Revision: 922204
- add patch from fedora to fix potential overflows
- add patches from opensuse to fix CVE-2015-8077 and CVE-2015-8078

* Sun Sep 27 2015 spuhler <spuhler> 2.4.18-1.mga6
+ Revision: 884294
- removed some commented out macros
  * the still expand with new rpm
- removed patch4 -p1 -b .autosieve.orig
  * the pacakge doesn't build anymore with this patch
  * neither Fedora nor opensuse uses it.
  * The last activity upstream on this: Dec, 22 2009 : Autosieve patch (version 0.6) released for Cyrus IMAPd 2.3.16
- update to vers, 2.4.18
  * This fixes security issue, bug #16823
- and these upstream bugs
  * Security fix: handle urlfetch range starting outside message range
  * A bunch of cleanups and fixes to compiling
  * A bunch of sieve cleanups
  * Enhanced SSL/TLS configuration options
  * Disable use of SSLv2/SSLv3
  * Allow SQL backend for mboxlist and statuscache (thanks Julien Coloos)
  * Fixed Task #116: correct LIST response for domains starting with ‘inbox.’
  * Fixed Task #76: fixed lmtpd userdeny db checks (thanks Leena Heino)
  * Fixed bug #3856: lmtpd now performs userdeny checks
  * Fixed bug #3848: support charset aliases in encoded headers
  * Fixed bug #3853: disconnect_on_vanished_mailbox: release mailbox lock before exiting (thanks Wolfgang Breyha)
  * Fixed bug #3415: fixed nntpd LIST/GROUP bug
  * Fixed bug #3784: no longer crash in THREAD REFERENCES when messages reference themselves
  * Fixed bug #3757: don’t segfault on mailbox close with no user

* Thu Jun 25 2015 sander85 <sander85> 2.4.17-21.mga6
+ Revision: 843891
- Rebuild for perl 5.22

* Tue Nov 25 2014 cjw <cjw> 2.4.17-20.mga5
+ Revision: 799124
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 2.4.17-19.mga5
+ Revision: 741977
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 2.4.17-18.mga5
+ Revision: 693720
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 2.4.17-17.mga5
+ Revision: 678659
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 jquelin <jquelin> 2.4.17-16.mga5
+ Revision: 632200
- perl 5.20.0 rebuild

* Sat Mar 22 2014 spuhler <spuhler> 2.4.17-15.mga5
+ Revision: 606561
- idled is need to run. Otherwise we'll see lots of errors
- uncommented the idled line

* Sat Mar 22 2014 spuhler <spuhler> 2.4.17-14.mga5
+ Revision: 606500
- added the conf-chroot.patch file
- activated ptloader (otherwise we get error messages)
- changed /etc/cyrus.conf to make it work with chrooted postfix
- added dir cyrus to /var/spool/postfix/extern/
  * to make it accessible for chrooted postfix (lmtp)
- remove some old kolab-2 stuff

* Sun Mar 16 2014 spuhler <spuhler> 2.4.17-13.mga5
+ Revision: 604056
- removed old kolab related patches
- removed init files
 * we use systemd
- deleted obsoleted cyrus.init file

* Sat Oct 19 2013 umeabot <umeabot> 2.4.17-12.mga4
+ Revision: 533504
- Mageia 4 Mass Rebuild

* Sat Aug 31 2013 fwang <fwang> 2.4.17-11.mga4
+ Revision: 473649
- we now build with libsasl3, which is much higher than 2.1.15

* Sat Aug 31 2013 spuhler <spuhler> 2.4.17-10.mga4
+ Revision: 473615
-rebuild against new cyrus-sasl lib

* Tue Aug 27 2013 luigiwalser <luigiwalser> 2.4.17-9.mga4
+ Revision: 472071
- rebuild for cyrus-sasl

* Wed May 29 2013 fwang <fwang> 2.4.17-8.mga4
+ Revision: 430388
- rebuild for new perl

* Mon May 06 2013 colin <colin> 2.4.17-7.mga3
+ Revision: 412409
- Silence a debug message for user_deny.db (lost when 2.3.16's user_deny_verbosity patch was dropped)

* Thu Apr 18 2013 spuhler <spuhler> 2.4.17-6.mga3
+ Revision: 410430
- added idled command
  corrected the config section so the idle file will actually be built.

* Tue Feb 26 2013 colin <colin> 2.4.17-5.mga3
+ Revision: 400404
- Some packaging fixups after re-enabling many patches
- Update patches for cyrus 2.4.x series
-   o Update the autocreate/autosieve patches for 2.4.x from vx.sk
-   o Disable rmquota patch build (no longer applies in 2.4.x, no update found)
-   o Update plaintext command line patch for 2.4.x
-   o Drop 64bit fixes patch (fixed upstream)
-   o Drop cyradm annotation patch (applied upstream)
-   o Drop string literals patch (fixed upstream)
-   o Drop statuscache verbosity patch (equivalent refactor upstream)
-   o Drop user_deny.db verbosity patch (equivalent refactor upstream)
-   o Drop sync client tls capability patch (fixed upstream)
-   o Drop perl compatibility patch (fixed upstream)
-   o Still disabled: mancyrusdb patch (needs rediff)
-   o Still disabled: md5/sha1 patch (refactored upstream - no longer needed?)

* Sat Feb 02 2013 spuhler <spuhler> 2.4.17-4.mga3
+ Revision: 394129
- in order to prevent to logs filling
  added touch /var/lib/imap/user_deny.db
  added chown cyrus:mail /var/lib/imap/user_deny.db

* Fri Jan 11 2013 umeabot <umeabot> 2.4.17-3.mga3
+ Revision: 348531
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 01 2013 spuhler <spuhler> 2.4.17-2.mga3
+ Revision: 336975
- bumped rel for rebuild
- replaced the obsolete comman 'runuser' with su -c

* Sat Dec 15 2012 spuhler <spuhler> 2.4.17-1.mga3
+ Revision: 331230
- upgrade to 2.4.17
- deleted signature file for version 2.4.16
- added signature file for version 2.4.17

* Tue Jul 31 2012 fwang <fwang> 2.4.16-3.mga3
+ Revision: 276368
- rebuild for db-5.3

* Fri Jul 27 2012 fwang <fwang> 2.4.16-2.mga3
+ Revision: 274848
- build db 5.2

* Sun Jun 10 2012 spuhler <spuhler> 2.4.16-1.mga3
+ Revision: 259168
- ugrade to version 2.4.16

* Thu May 31 2012 jquelin <jquelin> 2.4.13-7.mga3
+ Revision: 252135
- perl 5.16 rebuild

* Sat Apr 28 2012 tmb <tmb> 2.4.13-6.mga2
+ Revision: 233654
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sat Apr 28 2012 tmb <tmb> 2.4.13-5.mga2
+ Revision: 233547
- rebuild for versioned rpm-helper requires

* Mon Apr 23 2012 spuhler <spuhler> 2.4.13-4.mga2
+ Revision: 232749
- added missing cyr_systemd_helper file

* Fri Apr 20 2012 guillomovitch <guillomovitch> 2.4.13-3.mga2
+ Revision: 232094
- sanitize pre/post/preun/postun dependencies
- drop old ssl cert uppgrade procedure
- spec cleanup
- systemd support

* Fri Apr 20 2012 luigiwalser <luigiwalser> 2.4.13-2.mga2
+ Revision: 232025
- s/Mandriva/Mageia/ in ident string

* Thu Jan 26 2012 spuhler <spuhler> 2.4.13-1.mga2
+ Revision: 201745
- upgrade to 2.4.13
  deps
- upgrade to 2.4.13
+ guillomovitch <guillomovitch>
- rebuild for latest net-snmp

* Mon Jun 13 2011 sander85 <sander85> 2.3.16-5.mga2
+ Revision: 105538
- fix build
- perl 5.14

* Thu Mar 24 2011 dmorgan <dmorgan> 2.3.16-4.mga1
+ Revision: 77107
- Rebuild against new mysql

* Sat Feb 19 2011 spuhler <spuhler> 2.3.16-3.mga1
+ Revision: 54387
- increased rel from 1 to 2 for rebuild with new perl

* Sun Jan 23 2011 ennael <ennael> 2.3.16-2.mga1
+ Revision: 33420
- remove mdkversion
- imported package cyrus-imapd


* Tue Oct 12 2010 Funda Wang <fwang@mandriva.org> 2.3.16-2mdv2011.0
+ Revision: 585010
- rebuild

* Sun Oct 03 2010 Luca Berra <bluca@mandriva.org> 2.3.16-1mdv2011.0
+ Revision: 582777
- New version 2.3.16
  updated autosieve and autocreate patches
  removed Kolab imapd-annotate patch (merged upstream)
  reworked Kolab ldap patch
  reworked spec file (renumbered patches, removed compat macros)
  remove skiplist magic (it is already known to file)
  move ssl certificates from /etc/ssl to /etc/pki/tls
  add verbosity patches from simon matter
  add other misc patcges from simon
  fix cron daily script

* Sat Sep 11 2010 Thomas Spuhler <tspuhler@mandriva.org> 2.3.15-10mdv2011.0
+ Revision: 577601
- rebuilt with perl 5.12.2

* Sun Aug 01 2010 Luca Berra <bluca@mandriva.org> 2.3.15-9mdv2011.0
+ Revision: 564212
- rebuild for perl 5.12.1

* Wed Jul 21 2010 Jérôme Quelin <jquelin@mandriva.org> 2.3.15-8mdv2011.0
+ Revision: 556351
- rebuild for perl 5.12

* Mon Apr 05 2010 Funda Wang <fwang@mandriva.org> 2.3.15-7mdv2010.1
+ Revision: 531738
- rebuild for new openssl

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 2.3.15-6mdv2010.1
+ Revision: 511557
- rebuilt against openssl-0.9.8m

* Sat Jan 02 2010 Oden Eriksson <oeriksson@mandriva.com> 2.3.15-5mdv2010.1
+ Revision: 484970
- rebuild
- really link against bdb 4.8

* Fri Jan 01 2010 Funda Wang <fwang@mandriva.org> 2.3.15-4mdv2010.1
+ Revision: 484838
- rebuild for db 4.8

* Fri Jan 01 2010 Oden Eriksson <oeriksson@mandriva.com> 2.3.15-3mdv2010.1
+ Revision: 484744
- rebuilt against bdb 4.8

* Thu Oct 15 2009 Oden Eriksson <oeriksson@mandriva.com> 2.3.15-2mdv2010.0
+ Revision: 457611
- rebuilt against new net-snmp libs

* Thu Sep 10 2009 Oden Eriksson <oeriksson@mandriva.com> 2.3.15-1mdv2010.0
+ Revision: 436545
- 2.3.15
- rediffed P11,P23
- fixed linkage (P27)

* Sun Aug 09 2009 Oden Eriksson <oeriksson@mandriva.com> 2.3.14-2mdv2010.0
+ Revision: 413308
- rebuild

* Wed Apr 08 2009 Oden Eriksson <oeriksson@mandriva.com> 2.3.14-1mdv2009.1
+ Revision: 365126
- 2.3.14
- new autosieve and autocreate patches (P11,P13)
- rediffed the string format patch and added one more fix (P26)

* Tue Dec 16 2008 Oden Eriksson <oeriksson@mandriva.com> 2.3.13-1mdv2009.1
+ Revision: 314815
- 2.3.13
- really link against bdb-4.7 libs
- new upstream patches; P11,P13
- rediffed P17,P22,P23
- added P26 to make it build with -Werror=format-security (thanks pixel)
- enable the new mysql, postgresql and sqlite backends (enabled per default for now)

* Mon Dec 15 2008 Oden Eriksson <oeriksson@mandriva.com> 2.3.12-0.p2.5mdv2009.1
+ Revision: 314524
- rediffed fuzzy patches
- rebuilt against db4.7

* Tue Sep 16 2008 Luca Berra <bluca@mandriva.org> 2.3.12-0.p2.4mdv2009.0
+ Revision: 285186
- enable building of pts/ldap
- fix a problem with ptloader and sasl binds

* Thu Jul 17 2008 Oden Eriksson <oeriksson@mandriva.com> 2.3.12-0.p2.2mdv2009.0
+ Revision: 237677
- rebuild

* Sun May 18 2008 Oden Eriksson <oeriksson@mandriva.com> 2.3.12-0.p2.1mdv2009.0
+ Revision: 208742
- fix buildroot
- 2.3.12p2
- new P11,P13
- rediffed P17,P22

* Thu Apr 17 2008 Oden Eriksson <oeriksson@mandriva.com> 2.3.11-7mdv2009.0
+ Revision: 195128
- revert the "conform to the 2008 specs (don't start the services per
  default)" changes and let this be handled some other way...

* Wed Mar 26 2008 Oden Eriksson <oeriksson@mandriva.com> 2.3.11-6mdv2008.1
+ Revision: 190297
- don't start it per default

* Sat Feb 23 2008 Oden Eriksson <oeriksson@mandriva.com> 2.3.11-5mdv2008.1
+ Revision: 174079
- make it backportable

* Wed Jan 23 2008 Thierry Vignaud <tv@mandriva.org> 2.3.11-4mdv2008.1
+ Revision: 157244
- rebuild with fixed %%serverbuild macro

* Mon Jan 14 2008 Pixel <pixel@mandriva.com> 2.3.11-3mdv2008.1
+ Revision: 151350
- rebuild for perl-5.10.0

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Wed Jan 02 2008 Andreas Hasenack <andreas@mandriva.com> 2.3.11-2mdv2008.1
+ Revision: 140374
- updated to version 2.3.11

* Fri Dec 21 2007 Oden Eriksson <oeriksson@mandriva.com> 2.3.10-2mdv2008.1
+ Revision: 136258
- rebuilt against bdb 4.6.x libs
- rebuilt against openldap-2.4.7 libs

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - s/mandrake/mandriva/

* Mon Nov 05 2007 Andreas Hasenack <andreas@mandriva.com> 2.3.10-1mdv2008.1
+ Revision: 106031
- updated to version 2.3.10
- dropped db patch, same effect can be obtained with a configure option
- updated rmquota and auto* patches, redid cyradm_annotate one

  + Thierry Vignaud <tv@mandriva.org>
    - kill file require on chkconfig

* Wed Aug 08 2007 Oden Eriksson <oeriksson@mandriva.com> 2.3.8-4mdv2008.0
+ Revision: 60200
- rebuilt against new net-snmp libs

* Wed Jun 27 2007 Andreas Hasenack <andreas@mandriva.com> 2.3.8-3mdv2008.0
+ Revision: 45145
- rebuild with new serverbuild macro (-fstack-protector-all)

* Fri Jun 22 2007 Andreas Hasenack <andreas@mandriva.com> 2.3.8-2mdv2008.0
+ Revision: 43136
- using %%serverbuild macro

* Fri Jun 01 2007 Oden Eriksson <oeriksson@mandriva.com> 2.3.8-1mdv2008.0
+ Revision: 33602
- fix deps (net-snmp-mibs)
- add the /var/lib/net-snmp/cyrusMaster.conf file

* Mon May 28 2007 Oden Eriksson <oeriksson@mandriva.com> 2.3.8-0mdv2008.0
+ Revision: 32052
- 2.3.8
- dropped upstream patches; P9,P26,P27
- rediffed P17
- new upstream P11,P13,P14
- new P22,P23 (from gentoo)
- misc spec file fixes


* Wed Aug 16 2006 Andreas Hasenack <andreas@mandriva.com> 2.2.13-4mdv2007.0
+ Revision: 56199
- added parallel init information to the initscript (closes #24222)

* Sun Aug 06 2006 Andreas Hasenack <andreas@mandriva.com> 2.2.13-3mdv2007.0
+ Revision: 53022
- added some commented options to default imapd.conf (#22197)
- bunzip pam conf files
- import cyrus-imapd-2.2.13-2mdv2007.0

* Mon Jun 12 2006 Oden Eriksson <oeriksson@mandriva.com> 2.2.13-2mdv2007.0
- added P27 (#23051)

* Fri Jun 02 2006 Oden Eriksson <oeriksson@mandriva.com> 2.2.13-1mdv2007.0
- 2.2.13
- drop upstream patches; P0,P24,P25
- new P11
- rediffed patches; P21,P23
- cleaned up the spec file some
- make it backportable for older pam (S7,S8)

* Fri May 26 2006 Andreas Hasenack <andreas@mandriva.com> 2.2.12-22mdk
- added patch from CVS to fix a compatibility issue with sasl-2.1.22 final
  (imtest was incorrectly relying on a sasl bug that was fixed)
- removed buildrequires for XFree86-devel, couldn't find anything using it

* Sat May 13 2006 Stefan van der Eijk <stefan@eijk.nu> 2.2.12-21mdk
- rebuild for sparc

* Tue Apr 18 2006 Andreas Hasenack <andreas@mandriva.com> 2.2.12-20mdk
- added patch for timsieved, from amal@krasn.ru, to fix
  "Database handles remain at environment close" errors when using
  berkeley db for tls sessions

* Fri Mar 24 2006 Andreas Hasenack <andreas@mandriva.com> 2.2.12-19mdk
- updated auto-* patches

* Wed Jan 04 2006 Oden Eriksson <oeriksson@mandriva.com> 2.2.12-18mdk
- rebuilt against new net-snmp with new major (10)

* Wed Dec 21 2005 Oden Eriksson <oeriksson@mandriva.com> 2.2.12-17mdk
- rebuilt against net-snmp that has new major (9)

* Sun Nov 13 2005 Oden Eriksson <oeriksson@mandriva.com> 2.2.12-16mdk
- rebuilt against openssl-0.9.8a

* Thu Sep 08 2005 Andreas Hasenack <andreas@mandriva.com> 2.2.12-15mdk
- added patch from wes@umich.edu to avoid an off-by-one error which
  was causing cyrus to reject messages with long lines. Thanks to 
  joeghi for supplying a sample message and being patient.
  (fixes https://bugzilla.andrew.cmu.edu/show_bug.cgi?id=2676)

* Wed Aug 31 2005 Oden Eriksson <oeriksson@mandriva.com> 2.2.12-14mdk
- rebuilt against new openldap-2.3.6 libs

* Sat Aug 13 2005 Oden Eriksson <oeriksson@mandriva.com> 2.2.12-13mdk
- added one more annotation patch for kolab2 from the kolab cvs

* Fri Aug 05 2005 Oden Eriksson <oeriksson@mandriva.com> 2.2.12-12mdk
- revert the lib64 fixes

* Fri Aug 05 2005 Oden Eriksson <oeriksson@mandriva.com> 2.2.12-11mdk
- /usr/lib/cyrus-imapd is now /usr/lib64/cyrus-imap

* Sat Jul 30 2005 Andreas Hasenack <andreas@mandriva.com> 2.2.12-10mdk
- enabled virtual domains in ldap by default (needed by Kolab2)
- moved virtual domains' buildrequires (openldap) outside the nested %%if
  it was in (otherwise, it would only be required if snmp support was also
  enabled)

* Sat Jul 23 2005 Oden Eriksson <oeriksson@mandriva.com> 2.2.12-9mdk
- use a more descriptive build option for virtual domains in ldap (Andreas Hasenack)
- reworked the virtual domains in ldap patch (Andreas Hasenack)

* Thu Jul 07 2005 Oden Eriksson <oeriksson@mandriva.com> 2.2.12-8mdk
- added rediffed P21, P22 from the openpkg kolab2 packages
- added one gcc4 patch by Ondrej Sury

* Sun Mar 20 2005 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.2.12-7mdk
- fix #9788, conflicts is in the eyes of the beholder...

* Sat Mar 19 2005 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.2.12-6mdk
- only do the recursive chown if not upgrading (Luca Olivetti)

* Thu Mar 17 2005 Oden Eriksson <oden.eriksson@kvikkjokk.net> 2.2.12-5mdk
- make sure cyrus:mail owns /var/lib/imap 
  and /var/spool/imap in %%post

* Fri Mar 11 2005 Luca Berra <bluca@vodka.it> 2.2.12-4mdk
- revert liblm_sensors-devel change, fixed in net-snmp package

* Thu Mar 10 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.12-3mdk
- buildrequires: liblm_sensors-devel (cyrus-imapd/master)

* Fri Feb 25 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 2.2.12-2mdk
- rebuilt against the system bdb (P20)

* Tue Feb 15 2005 Luca Olivetti <luca@olivetti.cjb.net> 2.2.12-1mdk
- 2.2.12 (bug fix release)
- ugly compatibility macros for uglier release tag. See
  http://qa.mandrakesoft.com/twiki/bin/view/Main/DistroSpecificReleaseTag
- new autocreate and autosievefolder patches

* Thu Jan 13 2005 Luca Olivetti <luca@olivetti.cjb.net> 2.2.10-2mdk
- drop last digit from release tag
- fetchnews man page moved to cyrus-imapd-nntp subpackage (conflict with
  leafnode, thanks to Marek Kruz.el <marek@good.solutions.net.pl>
- new version of autocreate patch
- removed last chunk from 64bit fixes patch (the fault was in the
  previous autocreate patch, not in cyrus proper)

* Wed Nov 24 2004 Luca Olivetti <luca@olivetti.cjb.net> 2.2.10-1mdk
- 2.2.10 (security fixes)
- removed failing hunk in 64-bit fixes patch, it shouldn't be necessary
  anymore

* Wed Oct 27 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.2.8-3mdk
- some 64-bit fixes
- stick to /usr/lib/cyrus-imapd as _cyrexecdir

* Sun Aug 29 2004 Luca Berra <bluca@vodka.it> 2.2.8-2.mdk
- rebuild with db-4.2

* Sat Jul 31 2004 Luca Olivetti <luca@olivetti.cjb.net> 2.2.8-1mdk
- 2.2.8

* Wed Jul 28 2004 Luca Olivetti <luca@olivetti.cjb.net> 2.2.7-1mdk
- 2.2.7
- new autocreate,autosievefolder,rmquota patches
- removed p100 (quota patches from cvs)
- removed p2 and p3 (man pages fixes, fixed upstream)
- patch9 (munge8bit) and patch17 (plaintext) no longer patch html manpage
  (it's less tiresome to regenerate them with groff)
- removed patch19 (masssievec, fixed upstream)
- cleanup

* Fri Jul 02 2004 Luca Olivetti <luca@olivetti.cjb.net> 2.2.6-2mdk
- new imapcreate.pl script
- added quota patches from cvs

* Thu Jun 24 2004 Luca Olivetti <luca@olivetti.cjb.net> 2.2.6-1mdk
- 2.2.6
- changed version detection defines (and now it builds under 10.0 again)
- new autocreate,autosievefolder,rmquota patches
- removed patch0 (mandir, fixed upstream)
- removed patch1 (cflags, fixed upstream)
- rediffed patch9 (munge8bit)
- removed patch16 (netsnmp, , upstream package already has net-snmp support)
- rediffed patch17 (disallow plaintext login with a command line switch)
- removed patch100 (fix list command for non personal namespaces, fixed
  upstream)
- added BuildRequires libelfutils-devel for net-snmp

* Fri Jun 18 2004 Luca Berra <bluca@vodka.it> 2.2.3-7mdk
- updated p15 and rebuilt against updated net-snmp
- add 10.1 to recognized versions

* Tue Apr 06 2004 Florin <florin@mandrakesoft.com> 2.2.3.6
- update to 2.2.3 (merge with the L. Olivetti's work)

